@@ -7,8 +7,8 @@
 ;; Maintainer: Morgan Willcock <morgan@ice9.digital>
 ;; Package-Requires: ((emacs "28.1") (eldoc "1.14.0"))
 ;; URL: https://git.sr.ht/~mew/kixtart-mode
-;; Package-Version: 20260115.1810
-;; Package-Revision: a09f91c6dda7
+;; Package-Version: 20260203.1935
+;; Package-Revision: 5f5cb16dc76c
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -45,6 +45,7 @@
 
 ;;;; Faces
 
+;;;###autoload
 (defgroup kixtart-faces nil
   "Faces used by KiXtart Mode."
   :group 'kixtart
@@ -108,6 +109,7 @@
 
 ;;;; Customization
 
+;;;###autoload
 (defgroup kixtart nil
   "Major mode for editing KiXtart scripts."
   :tag "KiXtart"
@@ -301,12 +303,16 @@ Highlights all internal KiXtart commands, functions, and macros.")
       ;; Anchored match for function name.
       (,(kixtart-rx function-name)
        (unless (kixtart--in-comment-or-string-p)
-         (forward-comment (point-max))
-         (if (looking-at (kixtart-rx function-name))
-             (match-end 0)
-           ;; Skip highlighting anything else on this line by leaving point at
-           ;; the end of the line.
-           (end-of-line)))
+         (let ((start-pos (- (point) 8)))
+           (forward-comment (point-max))
+           (cond ((looking-at (kixtart-rx function-name))
+                  (put-text-property
+                   start-pos (match-end 0) 'font-lock-multiline t)
+                  (match-end 0))
+                 (t
+                  ;; Skip highlighting anything else on this line by leaving
+                  ;; point at the end of the line.
+                  (end-of-line)))))
        nil
        (0 kixtart-function-name-face))))
    kixtart-font-lock-keywords-2)
